aboutsummaryrefslogtreecommitdiffstats
path: root/configfs.c
diff options
context:
space:
mode:
Diffstat (limited to 'configfs.c')
-rw-r--r--configfs.c27
1 files changed, 15 insertions, 12 deletions
diff --git a/configfs.c b/configfs.c
index 2751d66..4f88bf8 100644
--- a/configfs.c
+++ b/configfs.c
@@ -148,9 +148,10 @@ static ssize_t cfg_snd_avirt_stream_map_store(struct config_item *item,
map = strsep((char **)&page, "\n");
- /* If already sealed, we cannot create the stream */
- if (snd_avirt_streams_sealed()) {
- D_ERRORK("Streams already sealed. Cannot set map: '%s'", map);
+ /* If already configured, we cannot create the stream */
+ if (snd_avirt_streams_configured()) {
+ D_ERRORK("Streams already configured. Cannot set map: '%s'",
+ map);
return -EPERM;
}
@@ -296,8 +297,9 @@ static void cfg_snd_avirt_route_release(struct config_item *item)
return;
}
- D_INFOK("Release route: %s", route->uid);
kfree(route);
+
+ D_INFOK("Release route: %s", route->uid);
}
static struct configfs_item_operations cfg_snd_avirt_stream_ops = {
@@ -402,15 +404,16 @@ cfg_snd_avirt_route_make_item(struct config_group *group, const char *name)
return &route->item;
}
-static ssize_t cfg_snd_avirt_stream_group_sealed_show(struct config_item *item,
- char *page)
+static ssize_t
+cfg_snd_avirt_stream_group_configured_show(struct config_item *item, char *page)
{
- return snprintf(page, PAGE_SIZE, "%d\n", snd_avirt_streams_sealed());
+ return snprintf(page, PAGE_SIZE, "%d\n",
+ snd_avirt_streams_configured());
}
-static ssize_t cfg_snd_avirt_stream_group_sealed_store(struct config_item *item,
- const char *page,
- size_t count)
+static ssize_t
+cfg_snd_avirt_stream_group_configured_store(struct config_item *item,
+ const char *page, size_t count)
{
unsigned long tmp;
char *p = (char *)page;
@@ -426,10 +429,10 @@ static ssize_t cfg_snd_avirt_stream_group_sealed_store(struct config_item *item,
return count;
}
-CONFIGFS_ATTR(cfg_snd_avirt_stream_group_, sealed);
+CONFIGFS_ATTR(cfg_snd_avirt_stream_group_, configured);
static struct configfs_attribute *cfg_snd_avirt_stream_group_attrs[] = {
- &cfg_snd_avirt_stream_group_attr_sealed,
+ &cfg_snd_avirt_stream_group_attr_configured,
NULL,
};